# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: process.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import event_pb2 as event__pb2
from . import entity_pb2 as entity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='process.proto',
  package='schema',
  syntax='proto3',
  serialized_options=b'\n\023com.phisuite.schemaB\014ProcessProtoP\001',
  serialized_pb=b'\n\rprocess.proto\x12\x06schema\x1a\x0c\x63ommon.proto\x1a\x0b\x65vent.proto\x1a\x0c\x65ntity.proto\"\x80\x02\n\x07Process\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1e\n\x06status\x18\x03 \x01(\x0e\x32\x0e.schema.Status\x12&\n\x05input\x18\x04 \x01(\x0b\x32\x17.schema.Process.Payload\x12\'\n\x06output\x18\x05 \x01(\x0b\x32\x17.schema.Process.Payload\x12\x1c\n\x05\x65rror\x18\x06 \x01(\x0b\x32\r.schema.Event\x1aG\n\x07Payload\x12\x1c\n\x05\x65vent\x18\x01 \x01(\x0b\x32\r.schema.Event\x12\x1e\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x0e.schema.Entity2\xe9\x01\n\nProcessAPI\x12*\n\x04List\x12\x0f.schema.Options\x1a\x0f.schema.Process0\x01\x12\'\n\x03Get\x12\x0f.schema.Options\x1a\x0f.schema.Process\x12*\n\x06\x43reate\x12\x0f.schema.Process\x1a\x0f.schema.Process\x12*\n\x06Update\x12\x0f.schema.Process\x1a\x0f.schema.Process\x12.\n\nDeactivate\x12\x0f.schema.Process\x1a\x0f.schema.ProcessB%\n\x13\x63om.phisuite.schemaB\x0cProcessProtoP\x01\x62\x06proto3'
  ,
  dependencies=[common__pb2.DESCRIPTOR,event__pb2.DESCRIPTOR,entity__pb2.DESCRIPTOR,])




_PROCESS_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='schema.Process.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='schema.Process.Payload.event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='schema.Process.Payload.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=323,
)

_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='schema.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.Process.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='schema.Process.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='schema.Process.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='schema.Process.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='schema.Process.output', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='schema.Process.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROCESS_PAYLOAD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=323,
)

_PROCESS_PAYLOAD.fields_by_name['event'].message_type = event__pb2._EVENT
_PROCESS_PAYLOAD.fields_by_name['entity'].message_type = entity__pb2._ENTITY
_PROCESS_PAYLOAD.containing_type = _PROCESS
_PROCESS.fields_by_name['status'].enum_type = common__pb2._STATUS
_PROCESS.fields_by_name['input'].message_type = _PROCESS_PAYLOAD
_PROCESS.fields_by_name['output'].message_type = _PROCESS_PAYLOAD
_PROCESS.fields_by_name['error'].message_type = event__pb2._EVENT
DESCRIPTOR.message_types_by_name['Process'] = _PROCESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), {

  'Payload' : _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {
    'DESCRIPTOR' : _PROCESS_PAYLOAD,
    '__module__' : 'process_pb2'
    # @@protoc_insertion_point(class_scope:schema.Process.Payload)
    })
  ,
  'DESCRIPTOR' : _PROCESS,
  '__module__' : 'process_pb2'
  # @@protoc_insertion_point(class_scope:schema.Process)
  })
_sym_db.RegisterMessage(Process)
_sym_db.RegisterMessage(Process.Payload)


DESCRIPTOR._options = None

_PROCESSAPI = _descriptor.ServiceDescriptor(
  name='ProcessAPI',
  full_name='schema.ProcessAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=326,
  serialized_end=559,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='schema.ProcessAPI.List',
    index=0,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='schema.ProcessAPI.Get',
    index=1,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='schema.ProcessAPI.Create',
    index=2,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='schema.ProcessAPI.Update',
    index=3,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='schema.ProcessAPI.Deactivate',
    index=4,
    containing_service=None,
    input_type=_PROCESS,
    output_type=_PROCESS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSAPI)

DESCRIPTOR.services_by_name['ProcessAPI'] = _PROCESSAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: entity.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='entity.proto',
  package='schema',
  syntax='proto3',
  serialized_options=b'\n\023com.phisuite.schemaB\013EntityProtoP\001',
  serialized_pb=b'\n\x0c\x65ntity.proto\x12\x06schema\x1a\x0c\x63ommon.proto\"\x84\x01\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1e\n\x06status\x18\x03 \x01(\x0e\x32\x0e.schema.Status\x12\x1b\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\r.schema.Field\x12\x1e\n\x07options\x18\x05 \x03(\x0b\x32\r.schema.Field2\x8c\x02\n\tEntityAPI\x12)\n\x04List\x12\x0f.schema.Options\x1a\x0e.schema.Entity0\x01\x12&\n\x03Get\x12\x0f.schema.Options\x1a\x0e.schema.Entity\x12(\n\x06\x43reate\x12\x0e.schema.Entity\x1a\x0e.schema.Entity\x12(\n\x06Update\x12\x0e.schema.Entity\x1a\x0e.schema.Entity\x12*\n\x08\x41\x63tivate\x12\x0e.schema.Entity\x1a\x0e.schema.Entity\x12,\n\nDeactivate\x12\x0e.schema.Entity\x1a\x0e.schema.EntityB$\n\x13\x63om.phisuite.schemaB\x0b\x45ntityProtoP\x01\x62\x06proto3'
  ,
  dependencies=[common__pb2.DESCRIPTOR,])




_ENTITY = _descriptor.Descriptor(
  name='Entity',
  full_name='schema.Entity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.Entity.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='schema.Entity.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='schema.Entity.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='schema.Entity.data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='schema.Entity.options', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=171,
)

_ENTITY.fields_by_name['status'].enum_type = common__pb2._STATUS
_ENTITY.fields_by_name['data'].message_type = common__pb2._FIELD
_ENTITY.fields_by_name['options'].message_type = common__pb2._FIELD
DESCRIPTOR.message_types_by_name['Entity'] = _ENTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'entity_pb2'
  # @@protoc_insertion_point(class_scope:schema.Entity)
  })
_sym_db.RegisterMessage(Entity)


DESCRIPTOR._options = None

_ENTITYAPI = _descriptor.ServiceDescriptor(
  name='EntityAPI',
  full_name='schema.EntityAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=174,
  serialized_end=442,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='schema.EntityAPI.List',
    index=0,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_ENTITY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='schema.EntityAPI.Get',
    index=1,
    containing_service=None,
    input_type=common__pb2._OPTIONS,
    output_type=_ENTITY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='schema.EntityAPI.Create',
    index=2,
    containing_service=None,
    input_type=_ENTITY,
    output_type=_ENTITY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='schema.EntityAPI.Update',
    index=3,
    containing_service=None,
    input_type=_ENTITY,
    output_type=_ENTITY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='schema.EntityAPI.Activate',
    index=4,
    containing_service=None,
    input_type=_ENTITY,
    output_type=_ENTITY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='schema.EntityAPI.Deactivate',
    index=5,
    containing_service=None,
    input_type=_ENTITY,
    output_type=_ENTITY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENTITYAPI)

DESCRIPTOR.services_by_name['EntityAPI'] = _ENTITYAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import common_pb2 as common__pb2
from . import entity_pb2 as entity__pb2


class EntityAPIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/schema.EntityAPI/List',
        request_serializer=common__pb2.Options.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Get = channel.unary_unary(
        '/schema.EntityAPI/Get',
        request_serializer=common__pb2.Options.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Create = channel.unary_unary(
        '/schema.EntityAPI/Create',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Update = channel.unary_unary(
        '/schema.EntityAPI/Update',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Activate = channel.unary_unary(
        '/schema.EntityAPI/Activate',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )
    self.Deactivate = channel.unary_unary(
        '/schema.EntityAPI/Deactivate',
        request_serializer=entity__pb2.Entity.SerializeToString,
        response_deserializer=entity__pb2.Entity.FromString,
        )


class EntityAPIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Activate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Deactivate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EntityAPIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=common__pb2.Options.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=common__pb2.Options.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Activate': grpc.unary_unary_rpc_method_handler(
          servicer.Activate,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
      'Deactivate': grpc.unary_unary_rpc_method_handler(
          servicer.Deactivate,
          request_deserializer=entity__pb2.Entity.FromString,
          response_serializer=entity__pb2.Entity.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'schema.EntityAPI', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common.proto',
  package='schema',
  syntax='proto3',
  serialized_options=b'\n\023com.phisuite.schemaB\013CommonProtoP\001',
  serialized_pb=b'\n\x0c\x63ommon.proto\x12\x06schema\"H\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1e\n\x06status\x18\x03 \x01(\x0e\x32\x0e.schema.Status\"\x8e\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.schema.Field.Type\"U\n\x04Type\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\t\n\x05\x45MAIL\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\x08\n\x04TIME\x10\x05\x12\t\n\x05\x43OLOR\x10\x06\"S\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x04type\x18\x02 \x01(\x0e\x32\x11.schema.File.Type\"\x1c\n\x04Type\x12\n\n\x06SINGLE\x10\x00\x12\x08\n\x04LIST\x10\x01*9\n\x06Status\x12\x0f\n\x0bUNACTIVATED\x10\x00\x12\r\n\tACTIVATED\x10\x01\x12\x0f\n\x0b\x44\x45\x41\x43TIVATED\x10\x02\x42$\n\x13\x63om.phisuite.schemaB\x0b\x43ommonProtoP\x01\x62\x06proto3'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='schema.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNACTIVATED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEACTIVATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=328,
  serialized_end=385,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
UNACTIVATED = 0
ACTIVATED = 1
DEACTIVATED = 2


_FIELD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='schema.Field.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMAIL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=156,
  serialized_end=241,
)
_sym_db.RegisterEnumDescriptor(_FIELD_TYPE)

_FILE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='schema.File.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=298,
  serialized_end=326,
)
_sym_db.RegisterEnumDescriptor(_FILE_TYPE)


_OPTIONS = _descriptor.Descriptor(
  name='Options',
  full_name='schema.Options',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.Options.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='schema.Options.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='schema.Options.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=96,
)


_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='schema.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.Field.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='schema.Field.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FIELD_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=241,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='schema.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='schema.File.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='schema.File.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=326,
)

_OPTIONS.fields_by_name['status'].enum_type = _STATUS
_FIELD.fields_by_name['type'].enum_type = _FIELD_TYPE
_FIELD_TYPE.containing_type = _FIELD
_FILE.fields_by_name['type'].enum_type = _FILE_TYPE
_FILE_TYPE.containing_type = _FILE
DESCRIPTOR.message_types_by_name['Options'] = _OPTIONS
DESCRIPTOR.message_types_by_name['Field'] = _FIELD
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Options = _reflection.GeneratedProtocolMessageType('Options', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:schema.Options)
  })
_sym_db.RegisterMessage(Options)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:schema.Field)
  })
_sym_db.RegisterMessage(Field)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:schema.File)
  })
_sym_db.RegisterMessage(File)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_namespace_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='phisuite.schema',  # Required
    version='0.0.0',  # Required
    description='Phi Suite Schema',  # Optional
    long_description=long_description,  # Optional
    long_description_content_type='text/markdown',  # Optional
    url='https://github.com/phisuite/schema.py',  # Optional
    author='Phi Skills',  # Optional
    author_email='phisuite@phiskills.com',  # Optional
    license='GNU GPLv3',  # Optional
    classifiers=[  # Optional
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development',
    ],
    keywords='Phi Suite Data Engineering',  # Optional
    packages=find_namespace_packages(include=['phisuite.*']),  # Required
    python_requires='>=3.8, <4',
    install_requires=['protobuf', 'grpcio'],  # Optional
    project_urls={  # Optional
        'Project website': 'https://phisuite.com',
        'Company website': 'https://phiskills.com',
        'Documentation': 'https://phisuite.com/doc',
        'Source': 'https://github.com/phisuite/schema.py',
    },
)
